package models

import (
	"errors"
	"log"
	"os"

	"gorm.io/driver/sqlite"
	"gorm.io/gorm"
)

var db *gorm.DB

func Init() {
	if _, err := os.Stat("/data/database.db"); errors.Is(err, os.ErrNotExist) {
		log.Printf("Creating sqlite database")
		_, err := os.Create("/data/database.db")
		if err != nil {
			log.Fatal(err)
		}
	}
	var err error

	db, err = gorm.Open(sqlite.Open("/data/database.db"), &gorm.Config{})
	if err != nil {
		log.Println("Failed to connect to db")
	}
	migrate()
}

func DB() *gorm.DB {
	if db == nil {
		Init()
	}
	return db
}

func create(d interface{}) error {
	return DB().Create(&d).Error
}

func read(d *interface{}) error {
	return DB().First(d, d).Error
}

func readAll(d interface{}, offset, limit int) ([]interface{}, error) {
	var data []interface{}
	err := DB().Offset(offset).Limit(limit).Where(&d).Find(&data).Error
	return data, err
}

func update(d interface{}, where string, f interface{}) error {
	return DB().Model(d).Where(where+" = ?", f).Updates(d).Error
}

func delete(d interface{}) error {

	return DB().Delete(d).Error
}
